@@ -18,6 +18,12 @@ class MatplotlibPlot(Plotter):
     def plot(self, *args, label="", **kwargs):
         self.cur_ax.plot(*args, label=label, **kwargs)
 
+    def xlim(self, row, col, limits):
+        self.cur_ax.set_xlim(limits)
+
+    def ylim(self, row, col, limits):
+        self.cur_ax.set_ylim(limits)
+
     def xlog(self):
         self.cur_ax.set_xscale("log")
 
@@ -59,14 +65,15 @@ class MatplotlibPlot(Plotter):
         pass
 
     def target_subplot(self, row, col):
-        if self.n_row == 1:
+        if self.n_row == 1 and self.n_col == 1:
+            self.cur_ax = self.axs
+        elif self.n_row == 1:
             self.cur_ax = self.axs[col - 1]
         elif self.n_col == 1:
             self.cur_ax = self.axs[row - 1]
         else:
             self.cur_ax = self.axs[row - 1][col - 1]
 
-    # self.args.plotsize[0], self.args.plotsize[1]
     def create_subplot(self, row, col):
         super().create_subplot(row, col)
         self.fig, self.axs = plt.subplots(row, col, figsize=self.args.plotsize)
